@@ -75,7 +75,7 @@ print.nma_data <- function(x, ..., n = 10) {
     s_ipd <- x$ipd %>%
       dplyr::distinct(.data$.study, .data$.trt) %>%
       dplyr::group_by(.data$.study) %>%
-      dplyr::summarise(Treatments = glue::glue("{dplyr::n()}: ",
+      dplyr::summarise("Treatment arms" = glue::glue("{dplyr::n()}: ",
                                               glue::glue_collapse(.data$.trt, sep = " | ", width = 0.8*cwidth))) %>%
       dplyr::rename(Study = .data$.study) %>%
       as.data.frame()
@@ -86,9 +86,9 @@ print.nma_data <- function(x, ..., n = 10) {
 
   if (has_agd_arm(x)) {
     s_agd_arm <- x$agd_arm %>%
-      dplyr::distinct(.data$.study, .data$.trt) %>%
+      dplyr::arrange(.data$.study, .data$.trt) %>%
       dplyr::group_by(.data$.study) %>%
-      dplyr::summarise(Treatments = glue::glue("{dplyr::n()}: ",
+      dplyr::summarise("Treatment arms" = glue::glue("{dplyr::n()}: ",
                                               glue::glue_collapse(.data$.trt, sep = " | ", width = 0.8*cwidth))) %>%
       dplyr::rename(Study = .data$.study) %>%
       as.data.frame()
@@ -99,9 +99,9 @@ print.nma_data <- function(x, ..., n = 10) {
 
   if (has_agd_contrast(x)) {
     s_agd_contrast <- x$agd_contrast %>%
-      dplyr::distinct(.data$.study, .data$.trt) %>%
+      dplyr::arrange(.data$.study, .data$.trt) %>%
       dplyr::group_by(.data$.study) %>%
-      dplyr::summarise(Treatments = glue::glue("{dplyr::n()}: ",
+      dplyr::summarise("Treatment arms" = glue::glue("{dplyr::n()}: ",
                                                glue::glue_collapse(.data$.trt, sep = " | ", width = 0.8*cwidth))) %>%
       dplyr::rename(Study = .data$.study) %>%
       as.data.frame()
@@ -526,6 +526,8 @@ get_nodesplits <- function(network, include_consistency = FALSE) {
   colnames(comparisons) <- c("trt1", "trt2")
 
   out <- dplyr::as_tibble(comparisons) %>%
+    # Remove edges of treatment against itself (from studies with multiple arms of the same treatment)
+    dplyr::filter(.data$trt1 != .data$trt2) %>%
     dplyr::mutate(trt1 = factor(.data$trt1, levels = levels(network$treatments)),
                   trt2 = factor(.data$trt2, levels = levels(network$treatments))) %>%
     dplyr::arrange(.data$trt1, .data$trt2) %>%
